summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit0d5a05983c0c2ba7a51bdeb1688dc232bacfa8ff (patch)
tree26e2e13d9f08727aa60872c0536662f8b2b5bf56
parent656e74dad5d31c4cc3eebdab9f58c679cfcc1ab0 (diff)
downloadkmplayer-0d5a0598.tar.gz
kmplayer-0d5a0598.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmplayer@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--src/kmplayer_koffice_part.cpp6
-rw-r--r--src/kmplayer_koffice_part.h2
-rw-r--r--src/kmplayer_part.cpp2
-rw-r--r--src/kmplayer_rp.cpp10
-rw-r--r--src/kmplayer_smil.cpp66
-rw-r--r--src/kmplayer_smil.h2
-rw-r--r--src/kmplayerapp.cpp44
-rw-r--r--src/kmplayerpartbase.cpp18
-rw-r--r--src/kmplayerplaylist.cpp22
-rw-r--r--src/kmplayerplaylist.h4
-rw-r--r--src/kmplayerprocess.cpp4
-rw-r--r--src/kmplayertvsource.cpp12
-rw-r--r--src/kmplayerview.h2
-rw-r--r--src/npplayer.c18
-rw-r--r--src/playlistview.cpp8
-rw-r--r--src/pref.cpp12
-rw-r--r--src/viewarea.cpp6
17 files changed, 119 insertions, 119 deletions
diff --git a/src/kmplayer_koffice_part.cpp b/src/kmplayer_koffice_part.cpp
index 85b27ac..b60f289 100644
--- a/src/kmplayer_koffice_part.cpp
+++ b/src/kmplayer_koffice_part.cpp
@@ -91,10 +91,10 @@ KParts::Part *KMPlayerFactory::createPartObject
//-----------------------------------------------------------------------------
-KOfficeMPlayer::KOfficeMPlayer (TQWidget *tqparentWidget, const char *widgetName, TQObject* tqparent, const char* name, bool singleViewMode)
- : KoDocument (tqparentWidget, widgetName, tqparent, name, singleViewMode),
+KOfficeMPlayer::KOfficeMPlayer (TQWidget *parentWidget, const char *widgetName, TQObject* tqparent, const char* name, bool singleViewMode)
+ : KoDocument (parentWidget, widgetName, tqparent, name, singleViewMode),
m_config (new KConfig ("kmplayerrc")),
- m_player (new KMPlayer (tqparentWidget, 0L, 0L, 0L, m_config))
+ m_player (new KMPlayer (parentWidget, 0L, 0L, 0L, m_config))
{
setInstance (KMPlayerFactory::instance (), false);
setReadWrite (false);
diff --git a/src/kmplayer_koffice_part.h b/src/kmplayer_koffice_part.h
index ca9002e..16ee9ab 100644
--- a/src/kmplayer_koffice_part.h
+++ b/src/kmplayer_koffice_part.h
@@ -63,7 +63,7 @@ class KOfficeMPlayer : public KoDocument {
Q_OBJECT
TQ_OBJECT
public:
- KOfficeMPlayer (TQWidget *tqparentWidget = 0, const char *widgetName = 0, TQObject* tqparent = 0, const char* name = 0, bool singleViewMode = false);
+ KOfficeMPlayer (TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject* tqparent = 0, const char* name = 0, bool singleViewMode = false);
~KOfficeMPlayer ();
virtual void paintContent (TQPainter& painter, const TQRect& rect,
diff --git a/src/kmplayer_part.cpp b/src/kmplayer_part.cpp
index 0064f41..d701d90 100644
--- a/src/kmplayer_part.cpp
+++ b/src/kmplayer_part.cpp
@@ -362,7 +362,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (TQWidget * wtqparent, const char
m_group.truncate (0);
kmplayerpart_static->partlist.push_back (this);
- TQWidget *pwidget = view ()->tqparentWidget ();
+ TQWidget *pwidget = view ()->parentWidget ();
if (pwidget) {
m_view->viewArea()->setPaletteBackgroundColor(pwidget->paletteBackgroundColor ());
m_view->viewer()->setBackgroundColor(pwidget->paletteBackgroundColor());
diff --git a/src/kmplayer_rp.cpp b/src/kmplayer_rp.cpp
index 7b0b44f..9ecdb62 100644
--- a/src/kmplayer_rp.cpp
+++ b/src/kmplayer_rp.cpp
@@ -252,7 +252,7 @@ KDE_NO_EXPORT bool RP::Image::isReady (bool postpone_if_not) {
KDE_NO_EXPORT Surface *RP::Image::surface () {
if (!img_surface && !cached_img.isEmpty ()) {
- Node * p = tqparentNode ().ptr ();
+ Node * p = parentNode ().ptr ();
if (p && p->id == RP::id_node_imfl) {
Surface *ps = static_cast <RP::Imfl *> (p)->surface ();
if (ps)
@@ -272,7 +272,7 @@ KDE_NO_EXPORT void RP::TimingsBase::activate () {
srcx = srcy = srcw = srch = 0;
for (Attribute * a= attributes ()->first ().ptr (); a; a = a->nextSibling ().ptr ()) {
if (a->name () == StringPool::attr_target) {
- for (NodePtr n = tqparentNode()->firstChild(); n; n= n->nextSibling())
+ for (NodePtr n = parentNode()->firstChild(); n; n= n->nextSibling())
if (convertNode <Element> (n)->
getAttribute ("handle") == a->value ())
target = n;
@@ -351,7 +351,7 @@ KDE_NO_EXPORT void RP::TimingsBase::begin () {
KDE_NO_EXPORT void RP::TimingsBase::update (int percentage) {
progress = percentage;
- Node * p = tqparentNode ().ptr ();
+ Node * p = parentNode ().ptr ();
if (p->id == RP::id_node_imfl)
static_cast <RP::Imfl *> (p)->tqrepaint ();
}
@@ -479,14 +479,14 @@ KDE_NO_EXPORT void RP::ViewChange::activate () {
KDE_NO_EXPORT void RP::ViewChange::begin () {
kdDebug () << "RP::ViewChange::begin" << endl;
setState (state_began);
- Node * p = tqparentNode ().ptr ();
+ Node * p = parentNode ().ptr ();
if (p->id == RP::id_node_imfl)
static_cast <RP::Imfl *> (p)->needs_scene_img++;
update (0);
}
KDE_NO_EXPORT void RP::ViewChange::finish () {
- Node * p = tqparentNode ().ptr ();
+ Node * p = parentNode ().ptr ();
if (p && p->id == RP::id_node_imfl)
static_cast <RP::Imfl *> (p)->needs_scene_img--;
TimingsBase::finish ();
diff --git a/src/kmplayer_smil.cpp b/src/kmplayer_smil.cpp
index 68734f9..00535dc 100644
--- a/src/kmplayer_smil.cpp
+++ b/src/kmplayer_smil.cpp
@@ -680,7 +680,7 @@ bool CalculatedSizer::applyRegPoints (Node * node, Single w, Single h,
node = SMIL::Smil::findSmilNode (node);
if (!node)
return false;
- node = static_cast <SMIL::Smil *> (node)->tqlayout_node.ptr ();
+ node = static_cast <SMIL::Smil *> (node)->layout_node.ptr ();
if (!node)
return false;
NodePtr c = node->firstChild ();
@@ -1611,7 +1611,7 @@ KDE_NO_EXPORT void SMIL::Smil::activate () {
//kdDebug () << "Smil::activate" << endl;
current_av_media_type = NodePtr ();
resolved = true;
- SMIL::Layout * tqlayout = convertNode <SMIL::Layout> (tqlayout_node);
+ SMIL::Layout * tqlayout = convertNode <SMIL::Layout> (layout_node);
if (tqlayout && tqlayout->region_surface) {
kdError() << "Layout already has a surface" << endl;
}
@@ -1622,16 +1622,16 @@ KDE_NO_EXPORT void SMIL::Smil::activate () {
}
KDE_NO_EXPORT void SMIL::Smil::deactivate () {
- if (tqlayout_node)
- convertNode <SMIL::Layout> (tqlayout_node)->tqrepaint ();
- if (tqlayout_node)
- convertNode <SMIL::Layout> (tqlayout_node)->region_surface = NULL;
+ if (layout_node)
+ convertNode <SMIL::Layout> (layout_node)->tqrepaint ();
+ if (layout_node)
+ convertNode <SMIL::Layout> (layout_node)->region_surface = NULL;
Mrl::getSurface(0L);
Mrl::deactivate ();
}
KDE_NO_EXPORT bool SMIL::Smil::handleEvent (EventPtr event) {
- return tqlayout_node ? tqlayout_node->handleEvent (event) : false;
+ return layout_node ? layout_node->handleEvent (event) : false;
}
KDE_NO_EXPORT void SMIL::Smil::closed () {
@@ -1650,7 +1650,7 @@ KDE_NO_EXPORT void SMIL::Smil::closed () {
}
for (NodePtr e = head->firstChild (); e; e = e->nextSibling ()) {
if (e->id == id_node_layout) {
- tqlayout_node = e;
+ layout_node = e;
} else if (e->id == id_node_title) {
TQString str = e->innerText ();
pretty_name = str.left (str.tqfind (TQChar ('\n')));
@@ -1663,7 +1663,7 @@ KDE_NO_EXPORT void SMIL::Smil::closed () {
src = elm->getAttribute ("content");
}
}
- if (!tqlayout_node) {
+ if (!layout_node) {
kdError () << "no <root-tqlayout>" << endl;
return;
}
@@ -1692,8 +1692,8 @@ KDE_NO_EXPORT bool SMIL::Smil::expose () const {
}
KDE_NO_EXPORT void SMIL::Smil::accept (Visitor * v) {
- if (active () && tqlayout_node)
- tqlayout_node->accept( v );
+ if (active () && layout_node)
+ layout_node->accept( v );
}
void SMIL::Smil::jump (const TQString & id) {
@@ -1702,7 +1702,7 @@ void SMIL::Smil::jump (const TQString & id) {
if (n->unfinished ())
kdDebug() << "Smil::jump node is unfinished " << id << endl;
else {
- for (NodePtr p = n; p; p = p->tqparentNode ()) {
+ for (NodePtr p = n; p; p = p->parentNode ()) {
if (p->unfinished () &&
p->id >= id_node_first_group &&
p->id <= id_node_last_group) {
@@ -1719,7 +1719,7 @@ void SMIL::Smil::jump (const TQString & id) {
}
SMIL::Smil * SMIL::Smil::findSmilNode (Node * node) {
- for (Node * e = node; e; e = e->tqparentNode ().ptr ())
+ for (Node * e = node; e; e = e->parentNode ().ptr ())
if (e->id == SMIL::id_node_smil)
return static_cast <SMIL::Smil *> (e);
return 0L;
@@ -1950,7 +1950,7 @@ KDE_NO_EXPORT void SMIL::RegionBase::updateDimensions () {
KDE_NO_EXPORT void SMIL::RegionBase::boundsUpdate () {
// if there is a region_surface and it's moved, do a limit tqrepaint
- NodePtr p = tqparentNode ();
+ NodePtr p = parentNode ();
if (p && (p->id==SMIL::id_node_region || p->id==SMIL::id_node_layout) &&
region_surface) {
RegionBase *pr = convertNode <SMIL::RegionBase> (p);
@@ -1964,7 +1964,7 @@ KDE_NO_EXPORT void SMIL::RegionBase::boundsUpdate () {
KDE_NO_EXPORT Surface *SMIL::RegionBase::surface () {
if (!region_surface) {
- Node *n = tqparentNode ().ptr ();
+ Node *n = parentNode ().ptr ();
if (n &&
(SMIL::id_node_region == n->id ||
SMIL::id_node_layout == n->id)) {
@@ -2005,7 +2005,7 @@ void SMIL::RegionBase::parseParam (const TrieString & name, const TQString & val
return; // smart update of old bounds to new moved one
}
}
- NodePtr p = tqparentNode ();
+ NodePtr p = parentNode ();
if (p &&(p->id==SMIL::id_node_region ||p->id==SMIL::id_node_layout))
convertNode <SMIL::RegionBase> (p)->updateDimensions ();
rect = rect.unite (SRect (x, y, w, h));
@@ -2023,7 +2023,7 @@ void SMIL::RegionBase::parseParam (const TrieString & name, const TQString & val
if (s) {
killWGet ();
need_tqrepaint = !cached_img.isEmpty ();
- Mrl *mrl = s->tqparentNode () ? s->tqparentNode ()->mrl () : NULL;
+ Mrl *mrl = s->parentNode () ? s->parentNode ()->mrl () : NULL;
TQString url = mrl ? KURL (mrl->absolutePath (), val).url () : val;
cached_img.setUrl (url);
if (cached_img.isEmpty ()) {
@@ -2034,8 +2034,8 @@ void SMIL::RegionBase::parseParam (const TrieString & name, const TQString & val
}
}
}
- if (need_tqrepaint && active () && surface() && region_surface->tqparentNode ())
- region_surface->tqparentNode ()->tqrepaint (rect);
+ if (need_tqrepaint && active () && surface() && region_surface->parentNode ())
+ region_surface->parentNode ()->tqrepaint (rect);
Element::parseParam (name, val);
}
@@ -2389,11 +2389,11 @@ KDE_NO_EXPORT bool SMIL::TimedMrl::keepContent (Node *n) {
TimedMrl * tm = convertNode <SMIL::TimedMrl> (n);
if (tm->runtime ()->timingstate == Runtime::timings_started)
return true;
- Node *p = n->tqparentNode ();
+ Node *p = n->parentNode ();
Node *np = tm;
while (p && id_node_body != p->id && !isTimedMrl (p)) {
np = p;
- p = p->tqparentNode ().ptr (); // skip anchors
+ p = p->parentNode ().ptr (); // skip anchors
}
if (tm->m_runtime && p && p->active ()) {
if (tm->runtime ()->timingstate == Runtime::timings_stopped)
@@ -2427,7 +2427,7 @@ KDE_NO_EXPORT bool SMIL::TimedMrl::keepContent (Node *n) {
}
KDE_NO_EXPORT SMIL::TimedMrl::Fill SMIL::TimedMrl::getDefaultFill (NodePtr n) {
- for (NodePtr p = n->tqparentNode (); p; p = p->tqparentNode ())
+ for (NodePtr p = n->parentNode (); p; p = p->parentNode ())
if (isTimedMrl (p)) {
SMIL::TimedMrl * tm = convertNode<SMIL::TimedMrl>(p);
if (tm->fill_def != fill_inherit)
@@ -2476,7 +2476,7 @@ KDE_NO_EXPORT void SMIL::GroupBase::setJumpNode (NodePtr n) {
for (NodePtr c = firstChild (); c; c = c->nextSibling ())
if (c->active ())
c->reset ();
- for (NodePtr c = n->tqparentNode (); c; c = c->tqparentNode ()) {
+ for (NodePtr c = n->parentNode (); c; c = c->parentNode ()) {
if (c.ptr () == this || c->id == id_node_body)
break;
if (c->id >= id_node_first_group && c->id <= id_node_last_group)
@@ -2746,11 +2746,11 @@ KDE_NO_CDTOR_EXPORT SMIL::Area::~Area () {
KDE_NO_EXPORT void SMIL::Area::activate () {
init ();
- if (tqparentNode () &&
- tqparentNode ()->id >= id_node_first_mediatype &&
- tqparentNode ()->id <= id_node_last_mediatype) {
- mediatype_activated = tqparentNode ()->connectTo (this, event_activated);
- mediatype_attach = tqparentNode ()->connectTo (this, mediatype_attached);
+ if (parentNode () &&
+ parentNode ()->id >= id_node_first_mediatype &&
+ parentNode ()->id <= id_node_last_mediatype) {
+ mediatype_activated = parentNode ()->connectTo (this, event_activated);
+ mediatype_attach = parentNode ()->connectTo (this, mediatype_attached);
}
Element::activate ();
}
@@ -2906,9 +2906,9 @@ KDE_NO_EXPORT void SMIL::MediaType::deactivate () {
}
KDE_NO_EXPORT void SMIL::MediaType::begin () {
- SMIL::Smil * s = Smil::findSmilNode (tqparentNode ().ptr ());
+ SMIL::Smil * s = Smil::findSmilNode (parentNode ().ptr ());
SMIL::Region * r = s ?
- findRegion (s->tqlayout_node, param (StringPool::attr_region)) : 0L;
+ findRegion (s->layout_node, param (StringPool::attr_region)) : 0L;
MediaTypeRuntime *tr = static_cast<MediaTypeRuntime*>(runtime ());
if (trans_timer) // eg transOut and we're repeating
document ()->cancelTimer (trans_timer);
@@ -3085,8 +3085,8 @@ bool SMIL::MediaType::handleEvent (EventPtr event) {
active_trans = NULL;
else
te->interval = trans_step++ < trans_steps;
- if (s && s->tqparentNode())
- s->tqparentNode()->tqrepaint (s->bounds);
+ if (s && s->parentNode())
+ s->parentNode()->tqrepaint (s->bounds);
return true;
} else if (te->timer_info->event_id == trans_out_timer_id) {
active_trans = trans_out;
@@ -3282,7 +3282,7 @@ KDE_NO_EXPORT bool SMIL::AnimateMotion::handleEvent (EventPtr event) {
KDE_NO_EXPORT void SMIL::Param::activate () {
setState (state_activated);
TQString name = getAttribute (StringPool::attr_name);
- Node * tqparent = tqparentNode ().ptr ();
+ Node * tqparent = parentNode ().ptr ();
if (!name.isEmpty () && tqparent && tqparent->isElementNode ())
static_cast<Element*>(tqparent)->setParam (name,
getAttribute (StringPool::attr_value));
diff --git a/src/kmplayer_smil.h b/src/kmplayer_smil.h
index 2a79e52..df1004a 100644
--- a/src/kmplayer_smil.h
+++ b/src/kmplayer_smil.h
@@ -411,7 +411,7 @@ public:
*/
Mrl * linkNode ();
NodePtrW current_av_media_type;
- NodePtrW tqlayout_node;
+ NodePtrW layout_node;
};
/**
diff --git a/src/kmplayerapp.cpp b/src/kmplayerapp.cpp
index 66d942f..21e8e44 100644
--- a/src/kmplayerapp.cpp
+++ b/src/kmplayerapp.cpp
@@ -349,9 +349,9 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
KMPlayer::NodePtr pl = new Playlist (app, source, true);
TQString data;
TQString pn;
- if (tqparentNode ()->id == KMPlayer::id_node_group_node) {
- data = tqparentNode ()->innerXML ();
- pn = tqparentNode ()->mrl ()->pretty_name;
+ if (parentNode ()->id == KMPlayer::id_node_group_node) {
+ data = parentNode ()->innerXML ();
+ pn = parentNode ()->mrl ()->pretty_name;
} else {
data = outerXML ();
pn = pretty_name.isEmpty () ? src : pretty_name;
@@ -363,8 +363,8 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
pl->normalize ();
KMPlayer::NodePtr cur = pl->firstChild ();
pl->mrl ()->resolved = !!cur;
- if (tqparentNode ()->id == KMPlayer::id_node_group_node && cur) {
- KMPlayer::NodePtr sister = tqparentNode ()->firstChild ();
+ if (parentNode ()->id == KMPlayer::id_node_group_node && cur) {
+ KMPlayer::NodePtr sister = parentNode ()->firstChild ();
while (sister && cur && sister.ptr () != this) {
sister = sister->nextSibling ();
cur = cur->nextSibling ();
@@ -1522,16 +1522,16 @@ KDE_NO_EXPORT void KMPlayerApp::menuDropInList () {
KMPlayer::NodePtr n = static_cast<KMPlayer::PlayListItem*>(m_drop_after)->node;
KMPlayer::NodePtr pi;
for (int i = m_drop_list.size (); n && (i > 0 || manip_node); i--) {
- if (manip_node && manip_node->tqparentNode ()) {
+ if (manip_node && manip_node->parentNode ()) {
pi = manip_node;
manip_node = 0L;
- pi->tqparentNode ()->removeChild (pi);
+ pi->parentNode ()->removeChild (pi);
} else
pi = new PlaylistItem(playlist, this,false, m_drop_list[i-1].url());
if (n == playlist || m_drop_after->isOpen ())
n->insertBefore (pi, n->firstChild ());
else
- n->tqparentNode ()->insertBefore (pi, n->nextSibling ());
+ n->parentNode ()->insertBefore (pi, n->nextSibling ());
}
m_view->playList()->updateTree (playlist_id, playlist, pi, true, false);
}
@@ -1544,13 +1544,13 @@ KDE_NO_EXPORT void KMPlayerApp::menuDropInGroup () {
if (n == playlist || m_drop_after->isOpen ())
n->insertBefore (g, n->firstChild ());
else
- n->tqparentNode ()->insertBefore (g, n->nextSibling ());
+ n->parentNode ()->insertBefore (g, n->nextSibling ());
KMPlayer::NodePtr pi;
for (int i = 0; i < m_drop_list.size () || manip_node; ++i) {
- if (manip_node && manip_node->tqparentNode ()) {
+ if (manip_node && manip_node->parentNode ()) {
pi = manip_node;
manip_node = 0L;
- pi->tqparentNode ()->removeChild (pi);
+ pi->parentNode ()->removeChild (pi);
} else
pi = new PlaylistItem (playlist,this, false, m_drop_list[i].url ());
g->appendChild (pi);
@@ -1565,36 +1565,36 @@ KDE_NO_EXPORT void KMPlayerApp::menuCopyDrop () {
if (n == playlist || m_drop_after->isOpen ())
n->insertBefore (pi, n->firstChild ());
else
- n->tqparentNode ()->insertBefore (pi, n->nextSibling ());
+ n->parentNode ()->insertBefore (pi, n->nextSibling ());
m_view->playList()->updateTree (playlist_id, playlist, pi, true, false);
}
}
KDE_NO_EXPORT void KMPlayerApp::menuDeleteNode () {
KMPlayer::NodePtr n;
- if (manip_node && manip_node->tqparentNode ()) {
- n = manip_node->previousSibling() ? manip_node->previousSibling() : manip_node->tqparentNode ();
- manip_node->tqparentNode ()->removeChild (manip_node);
+ if (manip_node && manip_node->parentNode ()) {
+ n = manip_node->previousSibling() ? manip_node->previousSibling() : manip_node->parentNode ();
+ manip_node->parentNode ()->removeChild (manip_node);
}
m_view->playList()->updateTree (manip_tree_id, 0L, n, true, false);
}
KDE_NO_EXPORT void KMPlayerApp::menuMoveUpNode () {
KMPlayer::NodePtr n = manip_node;
- if (n && n->tqparentNode () && n->previousSibling ()) {
+ if (n && n->parentNode () && n->previousSibling ()) {
KMPlayer::NodePtr prev = n->previousSibling ();
- n->tqparentNode ()->removeChild (n);
- prev->tqparentNode ()->insertBefore (n, prev);
+ n->parentNode ()->removeChild (n);
+ prev->parentNode ()->insertBefore (n, prev);
}
m_view->playList()->updateTree (manip_tree_id, 0L, n, true, false);
}
KDE_NO_EXPORT void KMPlayerApp::menuMoveDownNode () {
KMPlayer::NodePtr n = manip_node;
- if (n && n->tqparentNode () && n->nextSibling ()) {
+ if (n && n->parentNode () && n->nextSibling ()) {
KMPlayer::NodePtr next = n->nextSibling ();
- n->tqparentNode ()->removeChild (n);
- next->tqparentNode ()->insertBefore (n, next->nextSibling ());
+ n->parentNode ()->removeChild (n);
+ next->parentNode ()->insertBefore (n, next->nextSibling ());
}
m_view->playList()->updateTree (manip_tree_id, 0L, n, true, false);
}
@@ -1604,7 +1604,7 @@ KDE_NO_EXPORT void KMPlayerApp::playListItemMoved () {
KMPlayer::RootPlayListItem * ri = m_view->playList ()->rootItem (si);
kdDebug() << "playListItemMoved " << (ri->id == playlist_id) << !! si->node << endl;
if (ri->id == playlist_id && si->node) {
- KMPlayer::NodePtr p = si->node->tqparentNode ();
+ KMPlayer::NodePtr p = si->node->parentNode ();
if (p) {
p->removeChild (si->node);
m_view->playList()->updateTree(playlist_id,playlist,0L,false,false);
diff --git a/src/kmplayerpartbase.cpp b/src/kmplayerpartbase.cpp
index 7bd33bb..dedec80 100644
--- a/src/kmplayerpartbase.cpp
+++ b/src/kmplayerpartbase.cpp
@@ -661,7 +661,7 @@ KDE_NO_EXPORT void PartBase::playListItemExecuted (TQListViewItem * item) {
if (!src.isEmpty ()) {
PlayListItem * pi = static_cast <PlayListItem*>(item->tqparent());
if (pi) {
- for (NodePtr e = pi->node; e; e = e->tqparentNode ()) {
+ for (NodePtr e = pi->node; e; e = e->parentNode ()) {
Mrl * mrl = e->mrl ();
if (mrl)
src = KURL (mrl->absolutePath (), src).url ();
@@ -752,7 +752,7 @@ void PartBase::play () {
if (!lvi)
lvi = static_cast<PlayListItem*>(m_view->playList()->firstChild());
if (lvi)
- for (NodePtr n = lvi->node; n; n = n->tqparentNode ()) {
+ for (NodePtr n = lvi->node; n; n = n->parentNode ()) {
if (n->isPlayable ()) {
m_source->setCurrent (n);
break;
@@ -1040,7 +1040,7 @@ void Source::playCurrent () {
if (!m_current)
m_document->activate ();
else { // ugly code duplicate w/ back_request
- for (NodePtr p = m_current->tqparentNode(); p; p = p->tqparentNode())
+ for (NodePtr p = m_current->parentNode(); p; p = p->parentNode())
p->state = Element::state_activated;
m_current->activate ();
}
@@ -1141,7 +1141,7 @@ void Source::stateElementChanged (Node * elm, Node::State os, Node::State ns) {
} else if (ns == Node::state_activated &&
elm->isPlayable () &&
elm->mrl ()->view_mode == Mrl::SingleMode) {
- Node *p = elm->tqparentNode();
+ Node *p = elm->parentNode();
if (!p || !p->mrl () || p->mrl ()->view_mode == Mrl::SingleMode)
// make sure we don't set current to nested document
m_current = elm;
@@ -1181,7 +1181,7 @@ void Source::insertURL (NodePtr node, const TQString & mrl, const TQString & tit
kdError () << "try to append url to itself" << endl;
else {
int depth = 0; // cache this?
- for (NodePtr e = node; e->tqparentNode (); e = e->tqparentNode ())
+ for (NodePtr e = node; e->parentNode (); e = e->parentNode ())
++depth;
if (depth < 40) {
node->appendChild (new GenericURL (m_document, KURL::decode_string (url.url ()), title.isEmpty() ? KURL::decode_string (mrl) : title));
@@ -1223,7 +1223,7 @@ void Source::backward () {
return;
}
} else
- m_back_request = m_back_request->tqparentNode ();
+ m_back_request = m_back_request->parentNode ();
}
m_back_request = 0L;
} else
@@ -1424,9 +1424,9 @@ void Source::stateChange(Process *p, Process::State olds, Process::State news) {
m_current->id < SMIL::id_node_last) {
playCurrent (); // just play back_request
} else {
- // sanitize pl having all tqparents of current activated
+ // sanitize pl having all parents of current activated
m_document->reset (); // deactivate everything
- for (NodePtr p = m_current->tqparentNode(); p; p = p->tqparentNode())
+ for (NodePtr p = m_current->parentNode(); p; p = p->parentNode())
p->state = Element::state_activated;
m_current->activate (); // calls requestPlayUrl
}
@@ -1790,7 +1790,7 @@ bool URLSource::resolveURL (NodePtr m) {
if (!mrl || mrl->src.isEmpty ())
return true;
int depth = 0;
- for (NodePtr e = m->tqparentNode (); e; e = e->tqparentNode ())
+ for (NodePtr e = m->parentNode (); e; e = e->parentNode ())
++depth;
if (depth > 40)
return true;
diff --git a/src/kmplayerplaylist.cpp b/src/kmplayerplaylist.cpp
index 9e1db11..a33d374 100644
--- a/src/kmplayerplaylist.cpp
+++ b/src/kmplayerplaylist.cpp
@@ -308,7 +308,7 @@ void Node::clearChildren () {
void Node::appendChild (NodePtr c) {
document()->m_tree_version++;
- ASSERT (!c->tqparentNode ());
+ ASSERT (!c->parentNode ());
TreeNode<Node>::appendChild (c);
}
@@ -316,7 +316,7 @@ void Node::insertBefore (NodePtr c, NodePtr b) {
if (!b) {
appendChild (c);
} else {
- ASSERT (!c->tqparentNode ());
+ ASSERT (!c->parentNode ());
document()->m_tree_version++;
if (b->m_prev) {
b->m_prev->m_next = c;
@@ -669,7 +669,7 @@ Node::PlayType Mrl::playType () {
TQString Mrl::absolutePath () {
TQString path = src;
if (!path.isEmpty()) {
- for (NodePtr e = tqparentNode (); e; e = e->tqparentNode ()) {
+ for (NodePtr e = parentNode (); e; e = e->parentNode ()) {
Mrl * mrl = e->mrl ();
if (mrl && !mrl->src.isEmpty () && mrl->src != src) {
path = KURL (mrl->absolutePath (), src).url ();
@@ -737,7 +737,7 @@ void Mrl::begin () {
}
SurfacePtr Mrl::getSurface (NodePtr node) {
- for (NodePtr p = tqparentNode (); p; p = p->tqparentNode ())
+ for (NodePtr p = parentNode (); p; p = p->parentNode ())
if (p->mrl ())
return p->getSurface (node);
return 0L;
@@ -782,7 +782,7 @@ Surface::~Surface() {
}
void Surface::remove () {
- Surface *sp = tqparentNode ().ptr ();
+ Surface *sp = parentNode ().ptr ();
if (sp) {
sp->markDirty ();
sp->removeChild (this);
@@ -790,7 +790,7 @@ void Surface::remove () {
}
void Surface::markDirty () {
- for (Surface *s = this; s; s = s->tqparentNode ().ptr ())
+ for (Surface *s = this; s; s = s->parentNode ().ptr ())
s->dirty = true;
}
@@ -1218,10 +1218,10 @@ bool DocumentBuilder::endTag (const TQString & tag) {
(m_root_is_first || n != m_root)) {
while (n != m_node) {
kdWarning() << m_node->nodeName () << " not closed" << endl;
- if (m_root == m_node->tqparentNode ())
+ if (m_root == m_node->parentNode ())
break;
m_node->closed ();
- m_node = m_node->tqparentNode ();
+ m_node = m_node->parentNode ();
}
break;
}
@@ -1234,11 +1234,11 @@ bool DocumentBuilder::endTag (const TQString & tag) {
break;
} else
kdWarning () << "tag " << tag << " not " << n->nodeName () << endl;
- n = n ->tqparentNode ();
+ n = n ->parentNode ();
}
//kdDebug () << "end tag " << tag << endl;
m_node->closed ();
- m_node = m_node->tqparentNode ();
+ m_node = m_node->parentNode ();
}
return true;
}
@@ -1417,7 +1417,7 @@ void KMPlayer::readXML (NodePtr root, TQTextStream & in, const TQString & firstl
}
if (!in.atEnd ())
parser.parse (in);
- for (NodePtr e = root; e; e = e->tqparentNode ())
+ for (NodePtr e = root; e; e = e->parentNode ())
e->closed ();
//doc->normalize ();
//kdDebug () << root->outerXML ();
diff --git a/src/kmplayerprocess.cpp b/src/kmplayerprocess.cpp
index 415e28b..ec4fd31 100644
--- a/src/kmplayerprocess.cpp
+++ b/src/kmplayerprocess.cpp
@@ -594,7 +594,7 @@ bool MPlayer::run (const char * args, const char * pipe) {
fprintf (stderr, " -sid %d", sid);
*m_process << " -sid " << TQString::number (sid);
}
- for (NodePtr n = m_mrl; n; n = n->tqparentNode ()) {
+ for (NodePtr n = m_mrl; n; n = n->parentNode ()) {
if (n->id != id_node_group_node && n->id != id_node_playlist_item)
break;
TQString plops = convertNode <Element> (n)->getAttribute ("mplayeropts");
@@ -2181,7 +2181,7 @@ KDE_NO_EXPORT bool NpPlayer::deMediafiedPlay () {
break;
}
}
- for (NodePtr n = m_mrl; n; n = n->tqparentNode ()) {
+ for (NodePtr n = m_mrl; n; n = n->parentNode ()) {
Mrl *mrl = n->mrl ();
if (mrl && m_base_url.isEmpty ())
m_base_url = mrl->getAttribute ("pluginbaseurl");
diff --git a/src/kmplayertvsource.cpp b/src/kmplayertvsource.cpp
index eaa73c6..f970fbb 100644
--- a/src/kmplayertvsource.cpp
+++ b/src/kmplayertvsource.cpp
@@ -224,7 +224,7 @@ KDE_NO_EXPORT void TVInput::closed () {
}
KDE_NO_EXPORT void TVInput::setNodeName (const TQString & name) {
- Node * p = tqparentNode ().ptr ();
+ Node * p = parentNode ().ptr ();
TQString nm (name);
if (p && p->id == id_node_tv_device) {
int pos = name.tqfind (TQString (" - ") + p->mrl ()->pretty_name);
@@ -409,7 +409,7 @@ void KMPlayerTVSource::jump (KMPlayer::NodePtr e) {
readXML ();
} else {
m_current = e;
- for (; e; e = e->tqparentNode ()) {
+ for (; e; e = e->parentNode ()) {
if (e->id == id_node_tv_device) {
m_cur_tvdevice = e;
break;
@@ -436,14 +436,14 @@ KDE_NO_EXPORT void KMPlayerTVSource::buildArguments () {
KMPlayer::NodePtr elm = m_current;
if (elm && elm->id == id_node_tv_channel) {
channel = KMPlayer::convertNode <TVChannel> (elm);
- elm = elm->tqparentNode ();
+ elm = elm->parentNode ();
}
if (elm && elm->id == id_node_tv_input)
input = KMPlayer::convertNode <TVInput> (elm);
if (!(channel || (input && input->getAttribute ("tuner").isEmpty ())))
return;
m_cur_tvinput = input;
- m_cur_tvdevice = input->tqparentNode ();
+ m_cur_tvdevice = input->parentNode ();
static_cast <KMPlayer::View*>(m_player->view ())->playList ()->updateTree (0, m_cur_tvinput, m_current, true, false);
if (m_cur_tvdevice->id != id_node_tv_device) {
return;
@@ -698,8 +698,8 @@ KDE_NO_EXPORT void TVDeviceScannerSource::activate () {
KDE_NO_EXPORT void TVDeviceScannerSource::deactivate () {
kdDebug () << "TVDeviceScannerSource::deactivate" << endl;
if (m_tvdevice) {
- if (m_tvdevice->tqparentNode ())
- m_tvdevice->tqparentNode ()->removeChild (m_tvdevice);
+ if (m_tvdevice->parentNode ())
+ m_tvdevice->parentNode ()->removeChild (m_tvdevice);
m_tvdevice = 0L;
emit scanFinished (m_tvdevice);
}
diff --git a/src/kmplayerview.h b/src/kmplayerview.h
index e8a77a0..1782086 100644
--- a/src/kmplayerview.h
+++ b/src/kmplayerview.h
@@ -171,7 +171,7 @@ private:
TextEdit * m_multiedit;
// widget stack contains m_viewer, m_multiedit and m_picturewidget
TQWidgetStack * m_widgetstack;
- // widget that tqlayouts m_widgetstack for ratio setting and m_control_panel
+ // widget that layouts m_widgetstack for ratio setting and m_control_panel
ViewArea * m_view_area;
// playlist widget
PlayListView * m_playlist;
diff --git a/src/npplayer.c b/src/npplayer.c
index bb0dbd3..d338ec4 100644
--- a/src/npplayer.c
+++ b/src/npplayer.c
@@ -58,7 +58,7 @@ static gchar *callback_path;
static GModule *library;
static GtkWidget *xembed;
static Window socket_id;
-static Window tqparent_id;
+static Window parent_id;
static int top_w, top_h;
static int update_dimension_timer;
static int stdin_read_watch;
@@ -1354,19 +1354,19 @@ static void windowCreatedEvent (GtkWidget *w, gpointer d) {
(void)d;
print ("windowCreatedEvent\n");
socket_id = gtk_socket_get_id (GTK_SOCKET (xembed));
- if (tqparent_id) {
+ if (parent_id) {
print ("windowCreatedEvent %p\n", GTK_PLUG (w)->socket_window);
if (!GTK_PLUG (w)->socket_window)
- gtk_plug_construct (GTK_PLUG (w), tqparent_id);
+ gtk_plug_construct (GTK_PLUG (w), parent_id);
gdk_window_reparent( w->window,
GTK_PLUG (w)->socket_window
? GTK_PLUG (w)->socket_window
- : gdk_window_foreign_new (tqparent_id),
+ : gdk_window_foreign_new (parent_id),
0, 0);
gtk_widget_show_all (w);
- /*XRetqparentWindow (gdk_x11_drawable_get_xdisplay (w->window),
+ /*XReparentWindow (gdk_x11_drawable_get_xdisplay (w->window),
gdk_x11_drawable_get_xid (w->window),
- tqparent_id,
+ parent_id,
0, 0);*/
}
if (!callback_service) {
@@ -1425,7 +1425,7 @@ static gboolean initPlayer (void * p) {
(void)p;
window = callback_service
- ? gtk_plug_new (tqparent_id)
+ ? gtk_plug_new (parent_id)
: gtk_window_new (GTK_WINDOW_TOPLEVEL);
g_signal_connect (G_OBJECT (window), "delete_event",
G_CALLBACK (windowCloseEvent), NULL);
@@ -1446,7 +1446,7 @@ static gboolean initPlayer (void * p) {
gtk_container_add (GTK_CONTAINER (window), xembed);
- if (!tqparent_id) {
+ if (!parent_id) {
gtk_widget_set_size_request (window, 440, 330);
gtk_widget_show_all (window);
} else {
@@ -1518,7 +1518,7 @@ int main (int argc, char **argv) {
} else if (!strcmp (argv[i], "-m") && ++i < argc) {
mimetype = g_strdup (argv[i]);
} else if (!strcmp (argv [i], "-wid") && ++i < argc) {
- tqparent_id = strtol (argv[i], 0L, 10);
+ parent_id = strtol (argv[i], 0L, 10);
} else
object_url = g_strdup (argv[i]);
}
diff --git a/src/playlistview.cpp b/src/playlistview.cpp
index c13cb54..bf5b566 100644
--- a/src/playlistview.cpp
+++ b/src/playlistview.cpp
@@ -251,7 +251,7 @@ void PlayListView::updateTree (int id, NodePtr root, NodePtr active,
break; // found based on id
}
if (id == -1) { // wildcard id
- for (NodePtr n = root; n; n = n->tqparentNode ())
+ for (NodePtr n = root; n; n = n->parentNode ())
if (n == ritem->node) {
root = n;
break;
@@ -482,7 +482,7 @@ KDE_NO_EXPORT void PlayListView::itemDropped (TQDropEvent * de, TQListViewItem *
if (as_child)
n->insertBefore (ni, n->firstChild ());
else
- n->tqparentNode ()->insertBefore (ni, n->nextSibling ());
+ n->parentNode ()->insertBefore (ni, n->nextSibling ());
}
PlayListItem * citem = currentPlayListItem ();
NodePtr cn;
@@ -668,7 +668,7 @@ KDE_NO_EXPORT void PlayListView::slotFindNext () {
} else if (n->previousSibling ()) {
n = n->previousSibling ();
} else {
- for (n = n->tqparentNode (); n; n = n->tqparentNode ())
+ for (n = n->parentNode (); n; n = n->parentNode ())
if (n->previousSibling ()) {
n = n->previousSibling ();
break;
@@ -685,7 +685,7 @@ KDE_NO_EXPORT void PlayListView::slotFindNext () {
} else if (n->nextSibling ()) {
n = n->nextSibling ();
} else {
- for (n = n->tqparentNode (); n; n = n->tqparentNode ())
+ for (n = n->parentNode (); n; n = n->parentNode ())
if (n->nextSibling ()) {
n = n->nextSibling ();
break;
diff --git a/src/pref.cpp b/src/pref.cpp
index 670f4aa..c20ee14 100644
--- a/src/pref.cpp
+++ b/src/pref.cpp
@@ -139,15 +139,15 @@ KDE_NO_EXPORT void Preferences::setPage (const char * name) {
TQObject * o = child (name, TQFRAME_OBJECT_NAME_STRING);
if (!o) return;
TQFrame * page = static_cast <TQFrame *> (TQT_TQWIDGET(o));
- TQWidget * w = page->tqparentWidget ();
+ TQWidget * w = page->parentWidget ();
while (w && !w->inherits (TQTABWIDGET_OBJECT_NAME_STRING))
- w = w->tqparentWidget ();
+ w = w->parentWidget ();
if (!w) return;
TQTabWidget * t = static_cast <TQTabWidget*> (w);
t->setCurrentPage (t->indexOf(page));
- if (!t->tqparentWidget() || !t->tqparentWidget()->inherits (TQFRAME_OBJECT_NAME_STRING))
+ if (!t->parentWidget() || !t->parentWidget()->inherits (TQFRAME_OBJECT_NAME_STRING))
return;
- showPage (pageIndex (t->tqparentWidget ()));
+ showPage (pageIndex (t->parentWidget ()));
}
KDE_NO_EXPORT void Preferences::addPrefPage (PreferencesPage * page) {
@@ -188,9 +188,9 @@ KDE_NO_EXPORT void Preferences::removePrefPage(PreferencesPage * page) {
break;
}
if (!tab->count ()) {
- TQWidget * w = tab->tqparentWidget ();
+ TQWidget * w = tab->parentWidget ();
while (w && !w->inherits (TQFRAME_OBJECT_NAME_STRING))
- w = w->tqparentWidget ();
+ w = w->parentWidget ();
delete w;
entries.erase (en_it);
}
diff --git a/src/viewarea.cpp b/src/viewarea.cpp
index 3e5085e..229efca 100644
--- a/src/viewarea.cpp
+++ b/src/viewarea.cpp
@@ -188,7 +188,7 @@ KDE_NO_EXPORT void ViewSurface::resize (const SRect &r) {
KDE_NO_EXPORT IRect ViewSurface::toScreen (Single x, Single y, Single w, Single h) {
Matrix matrix (0, 0, xscale, yscale);
matrix.translate (bounds.x (), bounds.y ());
- for (SurfacePtr s = tqparentNode(); s; s = s->tqparentNode()) {
+ for (SurfacePtr s = parentNode(); s; s = s->parentNode()) {
matrix.transform(Matrix (0, 0, s->xscale, s->yscale));
matrix.translate (s->bounds.x (), s->bounds.y ());
}
@@ -1232,7 +1232,7 @@ static void followLink (SMIL::LinkingBase * link) {
else
kdError() << "In document jumps smil not found" << endl;
} else
- for (NodePtr p = link->tqparentNode (); p; p = p->tqparentNode ()) {
+ for (NodePtr p = link->parentNode (); p; p = p->parentNode ()) {
if (n->mrl () && n->mrl ()->opener == p) {
p->setState (Node::state_deferred);
p->mrl ()->setParam (StringPool::attr_src, link->href, 0L);
@@ -1251,7 +1251,7 @@ KDE_NO_EXPORT void MouseVisitor::visit (SMIL::Anchor * anchor) {
}
KDE_NO_EXPORT void MouseVisitor::visit (SMIL::Area * area) {
- NodePtr n = area->tqparentNode ();
+ NodePtr n = area->parentNode ();
if (n->id >= SMIL::id_node_first_mediatype &&
n->id < SMIL::id_node_last_mediatype) {
SMIL::MediaType * mt = convertNode <SMIL::MediaType> (n);
diff --git a/src/kmplayerplaylist.h b/src/kmplayerplaylist.h
index 0b3f29b..01e794c 100644
--- a/src/kmplayerplaylist.h
+++ b/src/kmplayerplaylist.h
@@ -165,7 +165,7 @@ public:
/*
* Base class for double linked tree nodes having tqparent/siblings/tqchildren.
* The linkage is a shared firstChild and weak tqparentNode.
*/
template <class T>
class KMPLAYER_EXPORT TreeNode : public ListNodeBase <T> {
@@ -176,7 +176,7 @@ public:
virtual void removeChild (typename Item<T>::SharedType c);
bool hasChildNodes () const { return m_first_child != 0L; }
- typename Item<T>::SharedType tqparentNode () const { return m_parent; }
+ typename Item<T>::SharedType parentNode () const { return m_parent; }
typename Item<T>::SharedType firstChild () const { return m_first_child; }
typename Item<T>::SharedType lastChild () const { return m_last_child; }
@@ -165,7 +165,7 @@ public:
/*
* Base class for double linked tree nodes having tqparent/siblings/tqchildren.
- * The linkage is a shared firstChild and weak tqparentNode.
+ * The linkage is a shared firstChild and weak parentNode.
*/
template <class T>